@@ -5,11 +5,13 @@ from pathlib import Path
 
 import dotenv
 
-from oeleo.connectors import register_password
+from checkers import ChecksumChecker
+from models import SimpleDbHandler
+from oeleo.connectors import register_password, LocalConnector, SharePointConnector
 from oeleo.console import console
-from oeleo.schedulers import SimpleScheduler, RichScheduler
+from oeleo.schedulers import RichScheduler, SimpleScheduler
 from oeleo.utils import logger
-from oeleo.workers import simple_worker, ssh_worker
+from oeleo.workers import simple_worker, ssh_worker, Worker, sharepoint_worker
 
 log = logger()
 
@@ -111,7 +113,7 @@ def example_check_first_then_run():
     log.info(f"Starting oeleo!")
 
     not_before = datetime(year=2021, month=3, day=1, hour=1, minute=0, second=0)
-    not_after = datetime(year=2022, month=7, day=1, hour=1, minute=0, second=0)
+    not_after = datetime(year=2022, month=8, day=30, hour=1, minute=0, second=0)
 
     my_filters = [
         ("not_before", not_before),
@@ -134,7 +136,21 @@ def example_check_first_then_run():
         worker.run()
 
 
-main = example_with_rich_scheduler
+def example_with_sharepoint_connector():
+    print(" example_check_first_then_run ".center(80, "-"))
+    log.setLevel(logging.DEBUG)
+    log.info(f"Starting oeleo!")
+
+    dotenv.load_dotenv()
+    worker = sharepoint_worker()
+    worker.connect_to_db()
+    worker.check(update_db=True)
+    worker.filter_local()
+    worker.run()
+
+
+main = example_with_sharepoint_connector
 
 if __name__ == "__main__":
     main()
+    # example_with_ssh_connection_and_rich_scheduler()
