@@ -1,16 +1,15 @@
-import asyncio
 import logging
 import time
 from datetime import datetime
 from typing import Protocol, Union
 
+from rich import print
 from rich.live import Live
 from rich.panel import Panel
-from rich import print
 
-from oeleo.layouts import create_layout, confirm
-from oeleo.workers import WorkerBase
+from oeleo.layouts import confirm, create_layout
 from oeleo.reporters import LayoutReporter
+from oeleo.workers import WorkerBase
 
 log = logging.getLogger("oeleo")
 
@@ -101,6 +100,7 @@ class RichScheduler(SchedulerBase):
         max_run_intervals=1000,
         update_db=True,
         force=False,
+        auto_accept_check=False,
     ):
         self.worker = worker
         self.state = {"iterations": 0}
@@ -109,8 +109,11 @@ class RichScheduler(SchedulerBase):
         self.max_run_intervals: int = max_run_intervals
         self.update_db: bool = update_db
         self.force: bool = force
+        self.auto_accept_check: bool = (
+            auto_accept_check  # nice to have when testing with pytest
+        )
         # self._last_update = None
-        self._sleep_interval = max(run_interval_time / 10, 1)
+        self._sleep_interval = 1  # second
         self._last_run = None
         self._run_counter = 0
         self.layout = None
@@ -136,15 +139,14 @@ class RichScheduler(SchedulerBase):
 
                 self.layout["left_footer"].update(Panel(f"CHECK..."))
                 self.worker.check(update_db=self.update_db, force=self.force)
-                if not confirm(self.layout):
-                    raise ScheduleAborted
+                if not self.auto_accept_check:
+                    if not confirm(self.layout):
+                        raise ScheduleAborted
 
                 self.worker.reporter.clear()
 
                 status_symbol = ":smiley:"
-                self.layout["status_footer"].update(
-                    Panel(status_symbol)
-                )
+                self.layout["status_footer"].update(Panel(status_symbol))
                 while True:
 
                     time.sleep(0.2)
@@ -165,16 +167,12 @@ class RichScheduler(SchedulerBase):
 
                     if self._run_counter == self.max_run_intervals - 2:
                         status_symbol = ":old_man_medium_skin_tone:"
-                        self.layout["status_footer"].update(
-                            Panel(status_symbol)
-                        )
+                        self.layout["status_footer"].update(Panel(status_symbol))
 
                     if self._run_counter >= self.max_run_intervals:
                         self.layout["middle_footer"].update(Panel("done"))
                         status_symbol = ":skull:"
-                        self.layout["status_footer"].update(
-                            Panel(status_symbol)
-                        )
+                        self.layout["status_footer"].update(Panel(status_symbol))
 
                         log.debug("-> BREAK")
                         time.sleep(0.2)
@@ -186,9 +184,7 @@ class RichScheduler(SchedulerBase):
                     )
                     self.worker.reporter.report(".")
 
-                    self.layout["status_footer"].update(
-                        Panel(":sleeping:")
-                    )
+                    self.layout["status_footer"].update(Panel(":sleeping:"))
                     while used_time < self.run_interval_time:
                         time.sleep(self._sleep_interval)
                         self.worker.reporter.report(".", same_line=True)
@@ -198,9 +194,7 @@ class RichScheduler(SchedulerBase):
                                 f"Idle for {round(used_time)}/{self.run_interval_time} s"
                             )
                         )
-                    self.layout["status_footer"].update(
-                        Panel(status_symbol)
-                    )
+                    self.layout["status_footer"].update(Panel(status_symbol))
         except (KeyboardInterrupt, ScheduleAborted):
             print("[bold red]Interrupted by user ...exiting")
 
