@@ -4,97 +4,26 @@ from asyncio import Protocol
 from dataclasses import dataclass, field
 from math import ceil
 from pathlib import Path
-from typing import Any, Generator, Union
+from typing import Any, Generator, Union, Callable
 
 from rich.panel import Panel
 from rich.text import Text
 
-from oeleo.layouts import N_ROWS_NOT_BODY, N_COLS_NOT_BODY
 from oeleo.checkers import ChecksumChecker
-from oeleo.connectors import Connector, LocalConnector, SSHConnector
+from oeleo.connectors import (
+    Connector,
+    LocalConnector,
+    SSHConnector,
+    SharePointConnector,
+)
 from oeleo.console import console
+from oeleo.layouts import N_COLS_NOT_BODY, N_ROWS_NOT_BODY
 from oeleo.models import DbHandler, MockDbHandler, SimpleDbHandler
+from oeleo.reporters import Reporter, ReporterBase
 
 log = logging.getLogger("oeleo")
 
 
-class ReporterBase(Protocol):
-    layout = None
-    lines: list = None
-
-    def report(self, status, events=None, same_line=False, replace_line=False):
-        ...
-
-    def clear(self):
-        ...
-
-
-class Reporter:
-    layout = None
-    lines = []
-
-    @staticmethod
-    def report(status, events=None, same_line=False, replace_line=False):
-        log.debug(status)
-
-    def clear(self):
-        pass
-
-
-class LayoutReporter:
-    def __init__(self, layout):
-        self.layout = layout
-        self.lines = []
-        self.max_lines = 200
-        self.min_lines = 100
-
-    def report(self, status, events=None, same_line=False, replace_line=False):
-        if same_line and len(self.lines):
-            self.lines[-1] = f"{self.lines[-1]}{status}"
-        elif replace_line and len(self.lines):
-            self.lines[-1] = f"{status}"
-        else:
-            self.lines.append(status)
-        if events:
-            log.debug(
-                f"Events ({events}) given - however, events are not implemented yet."
-            )
-
-        self._trim_if_needed()
-        body_panel = self._update_body_panel()
-        self.layout["body"].update(body_panel)
-
-    def clear(self):
-        self.lines = []
-
-    def _trim_if_needed(self):
-        if len(self.lines) > self.max_lines:
-            self.lines = self.lines[-self.min_lines :]
-
-    def _update_body_panel(self):
-        number_of_columns, number_of_rows = os.get_terminal_size()
-        number_of_rows -= N_ROWS_NOT_BODY
-        number_of_columns -= N_COLS_NOT_BODY
-
-        _lines = self.lines[-number_of_rows:]
-        needed_rows_due_to_wrapping = 0
-        _new_lines = []
-        for _line in reversed(_lines):
-            needed_rows_due_to_wrapping += ceil(
-                Text(_line).cell_len / number_of_columns
-            )
-            if needed_rows_due_to_wrapping < number_of_rows:
-                _new_lines.append(_line)
-            else:
-                break
-        _lines = reversed(_new_lines)
-
-        s = "\n".join(_lines)
-
-        p = Panel(s)
-        return p
-
-
 class WorkerBase(Protocol):
     checker: Any
     bookkeeper: DbHandler
@@ -167,6 +96,12 @@ class Worker(WorkerBase):
         bookkeeper: DbHandler to interact with the db
         local_connector: Connector = None
         external_connector: Connector = None
+
+    Additional optinal arguments:
+        dry_run: Bool
+        extension: str (with the .)
+        reporter: Reporter
+        external_name_generator: Callable that accepts the class instance and a string
     """
 
     checker: Any
@@ -176,7 +111,10 @@ class Worker(WorkerBase):
     external_connector: Connector = None
     extension: str = None
     reporter: ReporterBase = Reporter()
+    external_name_generator: Callable[[Any, Path], Path] = field(default=None)
+
     file_names: Generator[Path, None, None] = field(init=False, default=None)
+
     _external_name: Union[Path, str] = field(init=False, default="")
     _status: dict = field(init=False, default_factory=dict)
 
@@ -187,13 +125,14 @@ class Worker(WorkerBase):
         self.external_connector.connect()
 
     def connect_to_db(self):
-        self.status = ("state", "filter")
+        self.status = ("state", "connect-to-db")
         self.bookkeeper.initialize_db()
         log.debug(f"Connecting to db -> '{self.bookkeeper.db_name}' DONE")
 
     def filter_local(self, **kwargs):
         """Selects the files that should be processed."""
-
+        self.status = ("state", "filter-local")
+        self.status = ("filtered_once", True)
         local_files = self.local_connector.base_filter_sub_method(
             self.extension, **kwargs
         )
@@ -202,7 +141,7 @@ class Worker(WorkerBase):
 
     def filter_external(self, **kwargs):
         """Filter for external files that correspond to local ones."""
-        self.status = ("state", "filter")
+        self.status = ("state", "filter-external")
         external_files = self.external_connector.base_filter_sub_method(
             self.extension, **kwargs
         )
@@ -229,7 +168,6 @@ class Worker(WorkerBase):
 
         # cannot be a generator since we need to do a `if in` lookup:
         external_files = list(self.filter_external(**kwargs))
-        log.debug(external_files)
 
         number_of_local_files = 0
         number_of_external_duplicates = 0
@@ -310,10 +248,12 @@ class Worker(WorkerBase):
     def run(self):
         """Copy the files that needs to be copied and update the db."""
 
-        self.status = ("state", "run")
         log.debug("****** RUN:")
 
+        _minimum_one_file = False
+        self.status = ("state", "run")
         for f in self.file_names:
+            _minimum_one_file = True
             del self.status
             self.make_external_name(f)
             self.bookkeeper.register(f)
@@ -345,9 +285,13 @@ class Worker(WorkerBase):
                     )
 
             self.run_statistics()
+        if not _minimum_one_file:
+            self.reporter.report(
+                "No files to handle. Did you forget to run `worker.filter_local()`?"
+            )
 
     def run_statistics(self):
-        log.warning("deprecated")
+        log.warning("The method worker.run_statistic method is going to be deprecated")
         status = self.status
         f1 = status["name"]
         f2 = status["external_name"]
@@ -364,11 +308,14 @@ class Worker(WorkerBase):
         log.debug(txt, extra={"markup": True})
         return txt
 
-    def _create_external_name(self, f):
+    def _default_external_name_generator(self, f):
         return self.external_connector.directory / f.name
 
     def make_external_name(self, f):
-        name = self._create_external_name(f)
+        if self.external_name_generator is not None:
+            name = self.external_name_generator(self.external_connector, f)
+        else:
+            name = self._default_external_name_generator(f)
         self.external_name = name
         self.status = ("name", f.name)
         self.status = ("external_name", str(self.external_name))
@@ -384,7 +331,9 @@ class Worker(WorkerBase):
 
     @status.deleter
     def status(self):
-        self._status = {}
+        for k in self._status:
+            if k != "state":  # protected member
+                self._status[k] = None
 
     @property
     def external_name(self):
@@ -499,3 +448,77 @@ def ssh_worker(
         dry_run=dry_run,
     )
     return worker
+
+
+def sharepoint_worker(
+    base_directory_from: Union[Path, None] = None,
+    url: Union[Path, None] = None,
+    sitename: Union[str, None] = None,
+    doc_library_to: Union[str, None] = None,
+    db_name: Union[str, None] = None,
+    extension: str = None,
+    dry_run: bool = False,
+):
+    """Create a Worker with SharePointConnector.
+
+    Args:
+        base_directory_from: directory to copy from.
+        url: sharepoint url (e.g. https://yourcompany.sharepoint.com).
+        sitename: name of the specific SharePoint site.
+        doc_library_to: folder within the SharePoint site to copy to.
+        db_name: name of the database.
+        extension: file extension to filter on (for example '.csv').
+        dry_run: set to True if you would like to run without updating or moving anything.
+
+    Returns:
+        worker with SharePoint attached to it.
+    """
+
+    def external_name_generator(con, name):
+        return Path(name.name)
+
+    log.setLevel(logging.DEBUG)
+    log.debug(f"Starting oeleo!")
+    console.print(f"Starting oeleo!")
+
+    db_name = db_name or os.environ["OELEO_DB_NAME"]
+
+    base_directory_from = base_directory_from or Path(os.environ["OELEO_BASE_DIR_FROM"])
+    doc_library_to = doc_library_to or os.environ["OELEO_SHAREPOINT_DOC_LIBRARY"]
+    url = url or os.getenv("OELEO_SHAREPOINT_URL")
+    sitename = sitename or os.getenv("OELEO_SHAREPOINT_SITENAME")
+
+    extension = extension or os.environ["OELEO_FILTER_EXTENSION"]
+    username = os.getenv("OELEO_SHAREPOINT_USERNAME", None)
+
+    local_connector = LocalConnector(directory=base_directory_from)
+
+    external_connector = SharePointConnector(
+        username=username,
+        host=sitename,
+        url=url,
+        directory=doc_library_to,
+    )
+
+    bookkeeper = SimpleDbHandler(db_name)
+    checker = ChecksumChecker()
+
+    log.debug(
+        f"[bold]from:[/] [bold green]{local_connector.directory}[/]",
+        extra={"markup": True},
+    )
+    log.debug(
+        f"[bold]to  :[/] [bold blue]{external_connector.url}:{external_connector.directory}[/]",
+        extra={"markup": True},
+    )
+
+    worker = Worker(
+        checker=checker,
+        local_connector=local_connector,
+        external_connector=external_connector,
+        bookkeeper=bookkeeper,
+        extension=extension,
+        external_name_generator=external_name_generator,
+        dry_run=dry_run,
+    )
+    return worker
